@@ -15,7 +15,6 @@ subtype "${PKG}::choice0"
 has_element 'pw' =>
 	is => "rw",
 	isa => "${PKG}::choice0",
-	required => 1,
 	xml_nodeName => {
 		"pw" => "XML::EPP::Common::Password",
 		"ext" => "XML::EPP::Common::ExtPassword",
@@ -24,18 +23,6 @@ has_element 'pw' =>
 
 1;
 
-=head1 NAME
-
-? - implement ?
-
-=head1 SYNOPSIS
-
-TODO
-
-=head1 DESCRIPTION
-
-...
-
 =head2 XML Schema Definition
 
  <complexType name="authInfoType">
