@@ -11,7 +11,6 @@ has_element 'postal_info' =>
 	is => 'ro',
 	isa => 'XML::EPP::Contact::ChangePostalInfo',
 	xml_nodeName => 'postalInfo',
-	required => 1,
 	;
 
 use XML::EPP::Contact::E164;
@@ -48,23 +47,11 @@ has_element 'disclose' =>
 
 1;
 
-=head1 NAME
-
-? - implement ?
-
-=head1 SYNOPSIS
-
-TODO
-
-=head1 DESCRIPTION
-
-...
-
 =head2 XML Schema Definition
 
- <!--
- Data elements that can be changed.
- -->
+<!--
+Data elements that can be changed.
+-->
  <complexType name="chgType">
    <sequence>
      <element name="postalInfo" type="contact:chgPostalInfoType"
