@@ -22,7 +22,7 @@ use XML::EPP::Contact::Addr;
 has_element 'addr' =>
 	is => 'ro',
 	isa => 'XML::EPP::Contact::Addr',
-	xml_required => 0,
+	required => 0,
 	;
 
 has_attr 'type' =>
@@ -30,20 +30,6 @@ has_attr 'type' =>
 	isa => 'XML::EPP::Contact::postalInfoEnumType',
 	;
 
-1;
-
-=head1 NAME
-
-? - implement ?
-
-=head1 SYNOPSIS
-
-TODO
-
-=head1 DESCRIPTION
-
-...
-
 =head2 XML Schema Definition
 
  <complexType name="chgPostalInfoType">
