@@ -20,18 +20,6 @@ has_element 'name' =>
 
 1;
 
-=head1 NAME
-
-? - implement ?
-
-=head1 SYNOPSIS
-
-TODO
-
-=head1 DESCRIPTION
-
-...
-
 =head2 XML Schema Definition
 
  <complexType name="checkIDType">
