@@ -16,28 +16,15 @@ has_element 'items' =>
         is => 'ro',
         isa => 'ArrayRef[XML::EPP::Contact::Check::Status]',
         xml_nodeName => 'cd',
-	required => 1,
         ;
 
 1;
 
-=head1 NAME
-
-? - implement ?
-
-=head1 SYNOPSIS
-
-TODO
-
-=head1 DESCRIPTION
-
-...
-
 =head2 XML Schema Definition
 
- <!--
- <check> response elements.
- -->
+<!--
+<check> response elements.
+-->
  <complexType name="chkDataType">
    <sequence>
      <element name="cd" type="contact:checkType"
