@@ -26,13 +26,13 @@ use XML::EPP::Contact::E164;
 has_element 'voice' =>
 	is => 'ro',
 	isa => 'XML::EPP::Contact::E164',
-	xml_required => 0,
+	required => 0,
 	;
 
 has_element 'fax' =>
 	is => 'ro',
 	isa => 'XML::EPP::Contact::E164',
-	xml_required => 0,
+	required => 0,
 	;
 
 has_element 'email' =>
@@ -44,34 +44,22 @@ has_element 'auth_info' =>
 	is => 'ro',
 	isa => 'XML::EPP::Contact::AuthInfo',
 	xml_nodeName => 'authInfo',
-	required => 1,
 	;
 
 has_element 'disclose' =>
 	is => 'ro',
 	isa => 'XML::EPP::Contact::Disclose',
-	xml_required => 0,
+	required => 0,
 	;
 
 1;
 
-=head1 NAME
-
-? - implement ?
-
-=head1 SYNOPSIS
-
-TODO
-
-=head1 DESCRIPTION
-
-...
-
 =head2 XML Schema Definition
 
- <!--
- Child elements of the <create> command.
- -->
+
+<!--
+Child elements of the <create> command.
+-->
  <complexType name="createType">
    <sequence>
      <element name="id" type="eppcom:clIDType"/>
