@@ -23,23 +23,11 @@ has_element 'created' =>
 
 1;
 
-=head1 NAME
-
-? - implement ?
-
-=head1 SYNOPSIS
-
-TODO
-
-=head1 DESCRIPTION
-
-...
-
 =head2 XML Schema Definition
 
- <!--
- <create> response elements.
- -->
+<!--
+<create> response elements.
+-->
  <complexType name="creDataType">
    <sequence>
      <element name="id" type="eppcom:clIDType"/>
