@@ -52,18 +52,6 @@ has_attr 'flag' =>
 	isa => 'PRANG::XMLSchema::boolean'
 	;
 
-=head1 NAME
-
-? - implement ?
-
-=head1 SYNOPSIS
-
-TODO
-
-=head1 DESCRIPTION
-
-...
-
 =head2 XML Schema Definition
 
  <complexType name="discloseType">
