@@ -20,19 +20,7 @@ has_attr 'result' =>
 
 1;
 
-=head1 NAME
-
-XML::EPP::Contact::ID - implement paCLIDType
-
-=head1 SYNOPSIS
-
-TODO
-
-=head1 DESCRIPTION
-
-...
-
-=head2 XML Schema Definition
+=head2 XMLSchema definition
 
  <complexType name="paCLIDType">
    <simpleContent>
