@@ -14,14 +14,12 @@ use XML::EPP::Contact::ID;
 has_element 'id' =>
 	is => 'ro',
 	isa => 'XML::EPP::Contact::ID',
-	required => 1,
 	;
 
 has_element 'tx_id' =>
 	is => 'ro',
 	isa => 'XML::EPP::TrID',
 	xml_nodeName => 'paTRID',
-	required => 1,
 	;
 
 has_element 'completed' =>
@@ -32,23 +30,11 @@ has_element 'completed' =>
 
 1;
 
-=head1 NAME
-
-? - implement ?
-
-=head1 SYNOPSIS
-
-TODO
-
-=head1 DESCRIPTION
-
-...
-
 =head2 XML Schema Definition
 
- <!--
- Pending action notification response elements.
- -->
+<!--
+Pending action notification response elements.
+-->
  <complexType name="panDataType">
    <sequence>
      <element name="id" type="contact:paCLIDType"/>
