@@ -23,7 +23,6 @@ use XML::EPP::Contact::Addr;
 has_element 'addr' =>
 	is => 'ro',
 	isa => 'XML::EPP::Contact::Addr',
-	required => 1,
 	;
 
 has_attr 'type' =>
@@ -33,18 +32,6 @@ has_attr 'type' =>
 
 1;
 
-=head1 NAME
-
-? - implement ?
-
-=head1 SYNOPSIS
-
-TODO
-
-=head1 DESCRIPTION
-
-...
-
 =head2 XML Schema Definition
 
  <complexType name="postalInfoType">
