@@ -8,10 +8,9 @@ with 'XML::EPP::Domain::Node';
 use XML::EPP::Domain::Check::Name;
 has_element 'name_status' =>
         is => 'ro',
-        isa => 'XML::EPP::Domain::Check::Name',
+        isa => 'ArrayRef[XML::EPP::Domain::Check::Name]',
         xml_nodeName => 'name',
         handles => [qw(available name)],
-	required => 1,
         ;
 
 has_element 'reason' =>
@@ -23,18 +22,6 @@ has_element 'reason' =>
 
 1;
 
-=head1 NAME
-
-? - implement ?
-
-=head1 SYNOPSIS
-
-TODO
-
-=head1 DESCRIPTION
-
-...
-
 =head2 XML Schema Definition
 
  <complexType name="checkType">
