@@ -30,7 +30,7 @@ has_element 'ns' =>
 has_element 'registrant' =>
 	is => 'ro',
 	isa => 'XML::EPP::Common::clIDType',
-	xml_required => 0,
+    xml_required => 0,
 	;
 
 has_element 'contact' =>
@@ -43,41 +43,28 @@ has_element 'auth_info' =>
 	is => 'ro',
 	isa => 'XML::EPP::Domain::AuthInfo',
 	xml_nodeName => 'authInfo',
-	required => 1,
 	;
 
 1;
 
-=head1 NAME
-
-? - implement ?
-
-=head1 SYNOPSIS
-
-TODO
-
-=head1 DESCRIPTION
-
-...
-
 =head2 XML Schema Definition
 
- <!--
- Child elements of the <create> command.
- -->
- <complexType name="createType">
-  <sequence>
-    <element name="name" type="eppcom:labelType"/>
-    <element name="period" type="domain:periodType"
-     minOccurs="0"/>
-    <element name="ns" type="domain:nsType"
-     minOccurs="0"/>
-    <element name="registrant" type="eppcom:clIDType"
-     minOccurs="0"/>
-    <element name="contact" type="domain:contactType"
-     minOccurs="0" maxOccurs="unbounded"/>
-    <element name="authInfo" type="domain:authInfoType"/>
-  </sequence>
- </complexType>
+<!--
+Child elements of the <create> command.
+-->
+<complexType name="createType">
+ <sequence>
+   <element name="name" type="eppcom:labelType"/>
+   <element name="period" type="domain:periodType"
+    minOccurs="0"/>
+   <element name="ns" type="domain:nsType"
+    minOccurs="0"/>
+   <element name="registrant" type="eppcom:clIDType"
+    minOccurs="0"/>
+   <element name="contact" type="domain:contactType"
+    minOccurs="0" maxOccurs="unbounded"/>
+   <element name="authInfo" type="domain:authInfoType"/>
+ </sequence>
+</complexType>
 
 =cut
