@@ -20,27 +20,15 @@ has_attr 'hosts' =>
 
 1;
 
-=head1 NAME
-
-? - implement ?
-
-=head1 SYNOPSIS
-
-TODO
-
-=head1 DESCRIPTION
-
-...
-
 =head2 XML Schema Definition
 
- <complexType name="infoNameType">
-  <simpleContent>
-    <extension base = "eppcom:labelType">
-      <attribute name="hosts" type="domain:hostsType"
-       default="all"/>
-    </extension>
-  </simpleContent>
- </complexType>
+<complexType name="infoNameType">
+ <simpleContent>
+   <extension base = "eppcom:labelType">
+     <attribute name="hosts" type="domain:hostsType"
+      default="all"/>
+   </extension>
+ </simpleContent>
+</complexType>
 
 =cut
