@@ -2,7 +2,6 @@ package XML::EPP::Domain::Info::Response;
 
 use Moose;
 use PRANG::Graph;
-use XML::EPP::Domain;
 
 sub root_element { 'infData' }
 
@@ -70,7 +69,6 @@ has_element 'creator_id' =>
 has_element 'created' =>
 	is => "rw",
 	isa => "PRANG::XMLSchema::dateTime",
-	coerce => 1,
 	xml_nodeName => "crDate",
 	xml_required => 0,
 	;
@@ -85,7 +83,6 @@ has_element 'updated_by_id' =>
 has_element 'updated' =>
 	is => "rw",
 	isa => "PRANG::XMLSchema::dateTime",
-	coerce => 1,
 	xml_nodeName => 'upDate',
 	xml_required => 0,
 	;
@@ -93,17 +90,14 @@ has_element 'updated' =>
 has_element 'expiry_date' =>
 	is => "rw",
 	isa => "PRANG::XMLSchema::dateTime",
-	coerce => 1,
 	xml_required => 0,
 	xml_nodeName => 'exDate',
 	;
 
-has_element 'transfer_date' =>
+has_element 'trDate' =>
 	is => "rw",
 	isa => "PRANG::XMLSchema::dateTime",
-	coerce => 1,
 	xml_required => 0,
-	xml_nodeName => "trDate",
 	;
 
 has_element 'auth_info' =>
@@ -115,53 +109,41 @@ has_element 'auth_info' =>
 
 1;
 
-=head1 NAME
-
-? - implement ?
-
-=head1 SYNOPSIS
-
-TODO
-
-=head1 DESCRIPTION
-
-...
-
 =head2 XML Schema Definition
 
- <!--
- <info> response elements.
- -->
- <complexType name="infDataType">
-  <sequence>
-    <element name="name" type="eppcom:labelType"/>
-    <element name="roid" type="eppcom:roidType"/>
-    <element name="status" type="domain:statusType"
-     minOccurs="0" maxOccurs="11"/>
-    <element name="registrant" type="eppcom:clIDType"
-     minOccurs="0"/>
-    <element name="contact" type="domain:contactType"
-     minOccurs="0" maxOccurs="unbounded"/>
-    <element name="ns" type="domain:nsType"
-     minOccurs="0"/>
-    <element name="host" type="eppcom:labelType"
-     minOccurs="0" maxOccurs="unbounded"/>
-    <element name="clID" type="eppcom:clIDType"/>
-    <element name="crID" type="eppcom:clIDType"
-     minOccurs="0"/>
-    <element name="crDate" type="dateTime"
-     minOccurs="0"/>
-    <element name="upID" type="eppcom:clIDType"
-     minOccurs="0"/>
-    <element name="upDate" type="dateTime"
-     minOccurs="0"/>
-    <element name="exDate" type="dateTime"
-     minOccurs="0"/>
-    <element name="trDate" type="dateTime"
-     minOccurs="0"/>
-    <element name="authInfo" type="domain:authInfoType"
-     minOccurs="0"/>
-  </sequence>
- </complexType>
+<!--
+<info> response elements.
+-->
+<complexType name="infDataType">
+ <sequence>
+   <element name="name" type="eppcom:labelType"/>
+   <element name="roid" type="eppcom:roidType"/>
+   <element name="status" type="domain:statusType"
+    minOccurs="0" maxOccurs="11"/>
+   <element name="registrant" type="eppcom:clIDType"
+    minOccurs="0"/>
+   <element name="contact" type="domain:contactType"
+    minOccurs="0" maxOccurs="unbounded"/>
+   <element name="ns" type="domain:nsType"
+    minOccurs="0"/>
+   <element name="host" type="eppcom:labelType"
+    minOccurs="0" maxOccurs="unbounded"/>
+   <element name="clID" type="eppcom:clIDType"/>
+   <element name="crID" type="eppcom:clIDType"
+    minOccurs="0"/>
+   <element name="crDate" type="dateTime"
+    minOccurs="0"/>
+   <element name="upID" type="eppcom:clIDType"
+    minOccurs="0"/>
+   <element name="upDate" type="dateTime"
+    minOccurs="0"/>
+   <element name="exDate" type="dateTime"
+    minOccurs="0"/>
+   <element name="trDate" type="dateTime"
+    minOccurs="0"/>
+   <element name="authInfo" type="domain:authInfoType"
+    minOccurs="0"/>
+ </sequence>
+</complexType>
 
 =cut
