@@ -20,27 +20,15 @@ has_attr 'result' =>
 
 1;
 
-=head1 NAME
-
-? - implement ?
-
-=head1 SYNOPSIS
-
-TODO
-
-=head1 DESCRIPTION
-
-...
-
 =head2 XML Schema Definition
 
- <complexType name="paNameType">
-  <simpleContent>
-    <extension base="eppcom:labelType">
-      <attribute name="paResult" type="boolean"
-       use="required"/>
-    </extension>
-  </simpleContent>
- </complexType>
+<complexType name="paNameType">
+ <simpleContent>
+   <extension base="eppcom:labelType">
+     <attribute name="paResult" type="boolean"
+      use="required"/>
+   </extension>
+ </simpleContent>
+</complexType>
 
 =cut
