@@ -1,5 +1,20 @@
 package XML::EPP::Host::Status;
 
+# <!--
+# Status is a combination of attributes and an optional human-readable
+# message that may be expressed in languages other than English.
+# -->
+#  <complexType name="statusType">
+#    <simpleContent>
+#      <extension base="normalizedString">
+#        <attribute name="s" type="host:statusValueType"
+#         use="required"/>
+#        <attribute name="lang" type="language"
+#         default="en"/>
+#      </extension>
+#    </simpleContent>
+# </complexType>
+
 use Moose;
 use PRANG::Graph;
 with 'XML::EPP::Host::Node';
@@ -29,34 +44,3 @@ use Moose::Util::TypeConstraints;
 subtype "XML::EPP::Host::statusType" => as __PACKAGE__;
 
 1;
-
-=head1 NAME
-
-XML::EPP::Host::Status - implement statusType
-
-=head1 SYNOPSIS
-
-TODO
-
-=head1 DESCRIPTION
-
-...
-
-=head2
-
- <!--
- Status is a combination of attributes and an optional human-readable
- message that may be expressed in languages other than English.
- -->
- <complexType name="statusType">
-   <simpleContent>
-     <extension base="normalizedString">
-       <attribute name="s" type="host:statusValueType"
-        use="required"/>
-       <attribute name="lang" type="language"
-        default="en"/>
-     </extension>
-   </simpleContent>
-</complexType>
-
-=cut
